Struct google_firebasestorage1_beta::api::AddFirebaseRequest[][src]

pub struct AddFirebaseRequest { /* fields omitted */ }

The request used to link a Google Cloud Storage bucket to a Firebase project.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).