Struct google_firebasestorage1_beta::api::RemoveFirebaseRequest [−][src]
The request used to unlink a Google Cloud Storage bucket from a Firebase project.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- buckets remove firebase projects (request)